History
=======

4.0.6 (2019-02-09)
------------------

- Implement **Paranoid Text Spacing algorithm** v4
- Support Python 3.7
- Drop Python 2.7 support

3.3.0.1 (2018-01-20)
--------------------

- Support Python 3.6
- Add a method: ``pangu.spacing_file()``
- Add a command-line tool: ``pangu``

3.0.0 (2016-01-24)
------------------

- Support Python 3.5
- Refactoring
- Rename ``text_spacing()`` to ``spacing_text()``

2.5.6.3 (2015-05-18)
--------------------

- Add an alias to ``spacing()``: ``text_spacing()``
- Fix unicode issue in Python 2.x

2.5.6.2 (2015-05-17)
--------------------

- Fix setup.py

2.5.6 (2015-05-17)
------------------

- Synchronize version number with `pangu.js <https://github.com/vinta/pangu.js>`_
- Improve **Paranoid Text Spacing algorithm**

1.0.0 (2014-02-12)
------------------

- Hello World
